@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# In[42]:
+# In[300]:
 
 
 try:
@@ -12,10 +12,10 @@ except:
         pass
 
 
-# In[43]:
+# In[172]:
 
 
-version = '0.72'
+version = '0.73'
 
 import re
 import tempfile
@@ -33,7 +33,7 @@ import time
 
 # # Helper Functions
 
-# In[44]:
+# In[173]:
 
 
 def is_testing():
@@ -43,7 +43,7 @@ def is_testing():
         return False
 
 
-# In[45]:
+# In[174]:
 
 
 def isnotebook():
@@ -54,7 +54,7 @@ def isnotebook():
     return False
 
 
-# In[46]:
+# In[175]:
 
 
 def testPrint(*args):
@@ -64,13 +64,13 @@ def testPrint(*args):
 
 # # Timing
 
-# In[47]:
+# In[176]:
 
 
 timeSinceLastCallDict = {}
 
 
-# In[48]:
+# In[177]:
 
 
 def timeSinceLastCall(name):
@@ -83,7 +83,7 @@ def timeSinceLastCall(name):
     return name + ": " + time_s
 
 
-# In[49]:
+# In[178]:
 
 
 if is_testing():
@@ -92,7 +92,7 @@ if is_testing():
 
 # # Requiremtns
 
-# In[50]:
+# In[179]:
 
 
 requirements = []
@@ -124,7 +124,7 @@ import yaml
 
 # # Strings
 
-# In[51]:
+# In[180]:
 
 
 def sFloat0(f): return "{:0.0f}".format(f)
@@ -154,7 +154,7 @@ if is_testing():
     print(sFloatSci5(1.234567))
 
 
-# In[52]:
+# In[181]:
 
 
 def strUuid4():
@@ -165,14 +165,14 @@ def strUuid4():
     return uuid
 
 
-# In[53]:
+# In[182]:
 
 
 if is_testing():
     print(strUuid4())
 
 
-# In[54]:
+# In[183]:
 
 
 def strRand(n, num=True, upperCase=True, lowerCase=True):
@@ -184,7 +184,7 @@ def strRand(n, num=True, upperCase=True, lowerCase=True):
     return ''.join(random.choice(pool) for _ in range(n))
 
 
-# In[55]:
+# In[184]:
 
 
 if is_testing():
@@ -193,7 +193,7 @@ if is_testing():
     print(strRand(20, upperCase=False, lowerCase=False))
 
 
-# In[56]:
+# In[185]:
 
 
 def strMd5Pickle4(obj):
@@ -203,14 +203,14 @@ def strMd5Pickle4(obj):
     return md5.hexdigest()
 
 
-# In[57]:
+# In[186]:
 
 
 if is_testing():
     print(strMd5Pickle4(['a', 'b']))
 
 
-# In[58]:
+# In[187]:
 
 
 def strMd5String(s):
@@ -219,7 +219,7 @@ def strMd5String(s):
     return md5.hexdigest()
 
 
-# In[59]:
+# In[188]:
 
 
 if is_testing():
@@ -228,7 +228,7 @@ if is_testing():
 
 # # Multiprocess / Thread
 
-# In[60]:
+# In[299]:
 
 
 def mapThread(func, args, n=8):
@@ -253,14 +253,14 @@ if is_testing():
 
 # # Lists
 
-# In[61]:
+# In[190]:
 
 
 def liChunks(l, chunk_size):
     return [l[i:i + chunk_size] for i in range(0, len(l), chunk_size)]
 
 
-# In[62]:
+# In[191]:
 
 
 if is_testing():
@@ -269,7 +269,7 @@ if is_testing():
     print(liChunks(['a', 'b', 'c', 'd', 'e', 'f'], 3))
 
 
-# In[63]:
+# In[192]:
 
 
 def liSplit(a, number_of_splits):
@@ -277,7 +277,7 @@ def liSplit(a, number_of_splits):
     return [a[start:end] for start, end in zip(idxs[:-1], idxs[1:])]
 
 
-# In[64]:
+# In[193]:
 
 
 if is_testing():
@@ -289,7 +289,7 @@ if is_testing():
     print(liSplit(['a', 'b', 'c', 'd', 'e'], 6))
 
 
-# In[65]:
+# In[194]:
 
 
 def liJoin(l):
@@ -299,14 +299,14 @@ def liJoin(l):
     return out
 
 
-# In[66]:
+# In[195]:
 
 
 if is_testing():
     print(liJoin([['a', 'b', 'c'], ['d', 'e', 'f']]))
 
 
-# In[67]:
+# In[196]:
 
 
 def liFlatten(l):
@@ -323,7 +323,7 @@ def liFlatten(l):
         return l
 
 
-# In[68]:
+# In[197]:
 
 
 if is_testing():
@@ -333,7 +333,7 @@ if is_testing():
 
 # # List of Strings
 
-# In[69]:
+# In[198]:
 
 
 regex_cache = {}
@@ -343,35 +343,35 @@ def sListFilter(l, re_include=".*", re_exclude='^\b$'):
     return [e for e in l if regex_cache[re_include].search(e) and not regex_cache[re_exclude].search(e)]
 
 
-# In[70]:
+# In[199]:
 
 
 if is_testing():
     sListFilter(['good x', 'other good x', 'without the letter before y'])
 
 
-# In[71]:
+# In[200]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
 
 
-# In[72]:
+# In[201]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
 
 
-# In[73]:
+# In[202]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
 
 
-# In[74]:
+# In[203]:
 
 
 def lCsv(l, force_oneline=False):
@@ -387,21 +387,21 @@ def lCsv(l, force_oneline=False):
     return ", ".join([str(e) for e in l])
 
 
-# In[75]:
+# In[204]:
 
 
 if is_testing():
     print(lCsv(['a', 'b', 1, 3.14]))
 
 
-# In[76]:
+# In[205]:
 
 
 if is_testing():
     print(lCsv([['a', 'b'], 1, 3.14]))
 
 
-# In[77]:
+# In[206]:
 
 
 if is_testing():
@@ -410,7 +410,7 @@ if is_testing():
 
 # # Text files
 
-# In[78]:
+# In[207]:
 
 
 def txtread(path):
@@ -431,7 +431,7 @@ def txtwrite(path, txt):
             return f.write(txt)
 
 
-# In[79]:
+# In[208]:
 
 
 if is_testing():
@@ -440,21 +440,21 @@ if is_testing():
 
 # # YAML files
 
-# In[80]:
+# In[209]:
 
 
 def yamlwrite(path, obj):
     txtwrite(path, yaml.dump(obj))
 
 
-# In[81]:
+# In[210]:
 
 
 def yamlread(path):
     return yaml.safe_load(txtread(path=path))
 
 
-# In[82]:
+# In[211]:
 
 
 if is_testing():
@@ -467,7 +467,7 @@ if is_testing():
 
 # # List of Strings
 
-# In[83]:
+# In[212]:
 
 
 regex_cache = {}
@@ -479,35 +479,35 @@ def sListFilter(listOfStrings, re_include=".*", re_exclude='^\b$'):
 
 # ### Examples
 
-# In[84]:
+# In[213]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y']))
 
 
-# In[85]:
+# In[214]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
 
 
-# In[86]:
+# In[215]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
 
 
-# In[87]:
+# In[216]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
 
 
-# In[88]:
+# In[217]:
 
 
 if is_testing():
@@ -516,7 +516,7 @@ if is_testing():
 
 # # GCP Google Cloud Platform
 
-# In[89]:
+# In[218]:
 
 
 import warnings
@@ -540,7 +540,7 @@ def _gsBlob(path):
     return blob
 
 
-# In[90]:
+# In[219]:
 
 
 def gsGsToHttp(path):
@@ -550,7 +550,7 @@ def gsHttpToGs(path):
     return path.replace("https://storage.cloud.google.com/", "gs://").split("?")[0] # "?" is for possible "?authuser=0"
 
 
-# In[91]:
+# In[220]:
 
 
 def gsLs(path):
@@ -560,7 +560,7 @@ def gsLs(path):
     return ['gs://' + bucket + '/' + blob.name for blob in client.list_blobs(prefix=prefix)]
 
 
-# In[92]:
+# In[221]:
 
 
 def gsExists(path):
@@ -570,7 +570,7 @@ def gsExists(path):
     return client.blob(prefix).exists()
 
 
-# In[93]:
+# In[222]:
 
 
 def gsUploadFile(gsPath, path):
@@ -578,7 +578,7 @@ def gsUploadFile(gsPath, path):
     blob.upload_from_filename(path)
 
 
-# In[94]:
+# In[223]:
 
 
 def gsTxtread(path):
@@ -590,7 +590,7 @@ def gsTxtread(path):
     return blob.download_as_string().decode()
 
 
-# In[95]:
+# In[224]:
 
 
 def gsTxtwrite(path, s):
@@ -598,7 +598,7 @@ def gsTxtwrite(path, s):
     return blob.upload_from_string(s)
 
 
-# In[96]:
+# In[225]:
 
 
 def gsImwrite(path, img):
@@ -607,7 +607,7 @@ def gsImwrite(path, img):
     blob.upload_from_string(encimg.tobytes())
 
 
-# In[97]:
+# In[226]:
 
 
 def gsImread(path):
@@ -616,7 +616,7 @@ def gsImread(path):
     return cv2.imdecode(raw, 1)[:, :, [2, 1, 0]]
 
 
-# In[98]:
+# In[227]:
 
 
 def gsPklWrite(path, obj):
@@ -624,7 +624,7 @@ def gsPklWrite(path, obj):
     return blob.upload_from_string(pickle.dumps(obj, protocol=4))
 
 
-# In[99]:
+# In[228]:
 
 
 def gsPklRead(path):
@@ -634,7 +634,7 @@ def gsPklRead(path):
 
 # # Pickle
 
-# In[169]:
+# In[229]:
 
 
 def pklwrite(path, obj):
@@ -647,7 +647,7 @@ def pklwrite(path, obj):
             return pickle.dump(obj, f, protocol=4)
 
 
-# In[101]:
+# In[230]:
 
 
 def pklread(path):
@@ -658,7 +658,7 @@ def pklread(path):
             return pickle.load(f)
 
 
-# In[102]:
+# In[231]:
 
 
 if is_testing():
@@ -671,7 +671,7 @@ if is_testing():
 
 # # Images
 
-# In[103]:
+# In[232]:
 
 
 def imread(path):
@@ -705,7 +705,7 @@ def impad(img, top=0, bottom=0, left=0, right=0, color=255):
     return np.pad(img, [(top, bottom), (left, right), (0, 0)], 'constant', constant_values=color)
 
 
-# In[104]:
+# In[233]:
 
 
 def imshow(array, scale=1):
@@ -720,7 +720,7 @@ def imshow(array, scale=1):
         cv2.waitKey()
 
 
-# In[105]:
+# In[234]:
 
 
 if is_testing():
@@ -728,14 +728,14 @@ if is_testing():
     imshow(img)
 
 
-# In[106]:
+# In[235]:
 
 
 if is_testing():
     imshow('http://via.placeholder.com/70.png')
 
 
-# In[107]:
+# In[236]:
 
 
 def imscaleNN(img, s):
@@ -745,7 +745,7 @@ def imscaleBic(img, s):
     return cv2.resize(img, None, fx=s, fy=s, interpolation=cv2.INTER_CUBIC)
 
 
-# In[108]:
+# In[237]:
 
 
 if is_testing():
@@ -764,7 +764,7 @@ if is_testing():
         imshow(out_large_interbic)
 
 
-# In[109]:
+# In[238]:
 
 
 def imRepeat(img, height, width):
@@ -778,7 +778,7 @@ def imRepeat(img, height, width):
     return img
 
 
-# In[110]:
+# In[239]:
 
 
 if is_testing():
@@ -786,33 +786,33 @@ if is_testing():
     imshow(imRepeat(img_random_color_3x5, 7, 11), scale=10)
 
 
-# In[111]:
+# In[240]:
 
 
 def imNewWhite(height, width):
     return np.ones((height, width, 3)).astype(np.uint8) * 255
 
 
-# In[112]:
+# In[241]:
 
 
 if is_testing(): imshow(imNewWhite(10, 500) - 30)
 
 
-# In[113]:
+# In[242]:
 
 
 def imNewBlack(height, width):
     return np.zeros((height, width, 3)).astype(np.uint8)
 
 
-# In[114]:
+# In[243]:
 
 
 if is_testing(): imshow(imNewBlack(10, 500))
 
 
-# In[115]:
+# In[244]:
 
 
 def imAddNoiseGauss(img, std):
@@ -824,7 +824,7 @@ def imAddNoiseGauss(img, std):
 if is_testing(): imshow(imAddNoiseGauss(imread('http://via.placeholder.com/150.png'), 10))
 
 
-# In[116]:
+# In[245]:
 
 
 def imJpgDegradation(img, quality):
@@ -837,7 +837,7 @@ def imJpgDegradation(img, quality):
 if is_testing(): imshow(imJpgDegradation(imread('http://via.placeholder.com/150.png'), 15))
 
 
-# In[117]:
+# In[246]:
 
 
 def imCropCenter(img, size):
@@ -852,35 +852,35 @@ def imCropCenter(img, size):
     return img[h_start:h_end, w_start:w_end]
 
 
-# In[118]:
+# In[247]:
 
 
 if is_testing(): 
     imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 10))
 
 
-# In[119]:
+# In[248]:
 
 
 if is_testing(): 
     imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 49))
 
 
-# In[120]:
+# In[249]:
 
 
 if is_testing(): 
     imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 50))
 
 
-# In[121]:
+# In[250]:
 
 
 if is_testing(): 
     imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 100))
 
 
-# In[122]:
+# In[251]:
 
 
 def imCropRandom(img, size):
@@ -895,7 +895,7 @@ def imCropRandom(img, size):
     return img[h_start:h_end, w_start:w_end]
 
 
-# In[123]:
+# In[252]:
 
 
 if is_testing(): 
@@ -903,7 +903,7 @@ if is_testing():
     imshow(imCropRandom(imread('http://via.placeholder.com/40.png'), 39))
 
 
-# In[124]:
+# In[253]:
 
 
 def imGallery(imgs, pad=0):
@@ -934,7 +934,7 @@ def imGallery(imgs, pad=0):
     return out
 
 
-# In[125]:
+# In[254]:
 
 
 if is_testing():
@@ -942,49 +942,49 @@ if is_testing():
     listOfDummyImagesBlackToWhite = [imNewBlack(10, 10) + 25 * i for i in range(10)]
 
 
-# In[126]:
+# In[255]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:1]))
 
 
-# In[127]:
+# In[256]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:2]))
 
 
-# In[128]:
+# In[257]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:2], pad=1))
 
 
-# In[129]:
+# In[258]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:5], pad=1))
 
 
-# In[130]:
+# In[259]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:9], pad=1))
 
 
-# In[131]:
+# In[260]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:10], pad=1))
 
 
-# In[132]:
+# In[261]:
 
 
 if is_testing():
@@ -994,14 +994,14 @@ if is_testing():
 
 # # Files
 
-# In[133]:
+# In[262]:
 
 
 def fiFindByWildcard(wildcard):
     return natsort.natsorted(glob.glob(wildcard, recursive=True))
 
 
-# In[134]:
+# In[263]:
 
 
 if is_testing():
@@ -1030,7 +1030,7 @@ if is_testing():
         imshow(imGallery(imgs))
 
 
-# In[135]:
+# In[264]:
 
 
 def fiRemove(path):
@@ -1058,7 +1058,7 @@ def fiAgeHours(path):
     return (time.time() - os.stat(path)[stat.ST_MTIME]) / 3600
 
 
-# In[136]:
+# In[265]:
 
 
 if is_testing():
@@ -1090,7 +1090,7 @@ if is_testing():
         print("files: " + "\n".join(fiFindByWildcard(os.path.join(d, "**", "*"))))
 
 
-# In[137]:
+# In[266]:
 
 
 def fiUnzip(zip_path, out_dir=None, remove=False):
@@ -1105,7 +1105,7 @@ def fiUnzip(zip_path, out_dir=None, remove=False):
         zip.extractall(out_dir)
 
 
-# In[138]:
+# In[267]:
 
 
 def fiJoin(*args):
@@ -1117,7 +1117,7 @@ if is_testing():
 
 # # Jupyter
 
-# In[139]:
+# In[294]:
 
 
 def jnNbFullWidth():
@@ -1128,10 +1128,10 @@ def jnPandasSettings():
     pd.set_option('display.max_rows', 500)
     pd.set_option('display.max_columns', 500)
     pd.set_option('display.width', 1000)
-    pd.set_option('display.max_colwidth', None)
+    pd.set_option('display.max_colwidth', 100000)
 
 
-# In[140]:
+# In[269]:
 
 
 def jnImageRenderingPixelated():
@@ -1143,7 +1143,7 @@ def jnImageRenderingAuto():
     display(HTML('<style type = text/css> img { image-rendering: auto; } </style>'))
 
 
-# In[141]:
+# In[270]:
 
 
 def jnDefault():
@@ -1161,7 +1161,7 @@ if is_testing():
 
 
 
-# In[142]:
+# In[271]:
 
 
 def jnHtmlRow(strList, width=100):
@@ -1174,7 +1174,7 @@ if is_testing():
     
 
 
-# In[143]:
+# In[272]:
 
 
 def jnImgToHtmlB64(img):
@@ -1209,7 +1209,7 @@ def jnImageRow(imgs, names=None, width=100, external=False, title_img=None, titl
     display(HTML(html))
 
 
-# In[144]:
+# In[273]:
 
 
 if is_testing():
@@ -1217,7 +1217,7 @@ if is_testing():
    
 
 
-# In[145]:
+# In[274]:
 
 
 if is_testing():
@@ -1227,7 +1227,7 @@ if is_testing():
     jnImageRow(imgs, external=True, title='test')
 
 
-# In[146]:
+# In[275]:
 
 
 
@@ -1237,7 +1237,7 @@ if is_testing():
 
 # # Shell
 
-# In[147]:
+# In[276]:
 
 
 def shell(cmd):
@@ -1252,7 +1252,7 @@ def shell(cmd):
 
 # # GIT
 
-# In[148]:
+# In[277]:
 
 
 def gitGetHash():
@@ -1262,7 +1262,7 @@ if is_testing():
     print(gitGetHash())
 
 
-# In[149]:
+# In[278]:
 
 
 def gitGetBranch():
@@ -1272,7 +1272,7 @@ if is_testing():
     print(gitGetBranch())
 
 
-# In[150]:
+# In[279]:
 
 
 def gitGetMessage():
@@ -1282,7 +1282,7 @@ if is_testing():
     print(gitGetMessage())
 
 
-# In[151]:
+# In[280]:
 
 
 def gitGetAllFiles():
@@ -1292,7 +1292,7 @@ if is_testing():
     print(gitGetAllFiles())
 
 
-# In[152]:
+# In[281]:
 
 
 def gitListByTime(path=None):
@@ -1308,7 +1308,7 @@ if is_testing():
     print(gitListByTime()[-3:])
 
 
-# In[153]:
+# In[282]:
 
 
 def gitTime(path):
@@ -1319,7 +1319,7 @@ if is_testing():
     print(gitTime("__init__.py"))
 
 
-# In[154]:
+# In[283]:
 
 
 def gitTimeRaw(path):
@@ -1330,7 +1330,7 @@ if is_testing():
     print(gitTimeRaw("__init__.py"))
 
 
-# In[155]:
+# In[284]:
 
 
 def shellSortDirsBySize():
@@ -1342,14 +1342,14 @@ if is_testing():
 
 # # Package Files
 
-# In[156]:
+# In[285]:
 
 
 if is_testing():
     package_files = {}
 
 
-# In[157]:
+# In[286]:
 
 
 def shell(cmd):
@@ -1357,7 +1357,7 @@ def shell(cmd):
     return result.stdout.decode()
 
 
-# In[158]:
+# In[287]:
 
 
 if is_testing():
@@ -1389,7 +1389,7 @@ setup(
 )""".format(requirements=", ".join(["'" + r + "'" for r in requirements]), version=version)
 
 
-# In[159]:
+# In[288]:
 
 
 if is_testing():
@@ -1399,7 +1399,7 @@ description-file = README.md
 """
 
 
-# In[160]:
+# In[289]:
 
 
 if is_testing():
@@ -1422,14 +1422,14 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE."""
 
 
-# In[161]:
+# In[290]:
 
 
 if is_testing():
     package_files['README.md'] = ""
 
 
-# In[162]:
+# In[291]:
 
 
 if is_testing():
@@ -1438,7 +1438,7 @@ if is_testing():
     
 
 
-# In[163]:
+# In[292]:
 
 
 if is_testing():
@@ -1449,7 +1449,7 @@ lx/__init__.py
 """
 
 
-# In[164]:
+# In[293]:
 
 
 if is_testing():
